@@ -417,6 +417,8 @@ class ApiSession(Session):
         OneloginApiSession
         """
 
+        if max_api_retries == 0:
+            max_api_retries = 1
         if not idp_class:
             idp_class = ApiSession
         else:
@@ -1100,4 +1102,4 @@ class ApiSession(Session):
         logger.debug("Removed session for : %s", self.key)
         sessionDict.pop(self.key, None)
         return
-# End of file
+# End of file
\ No newline at end of file
